@@ -1,24 +1,22 @@
-/*
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-
-   xrdp: A Remote Desktop Protocol server.
-   Copyright (C) Jay Sorg 2004-2009
-
-   main define/macro file
-
-*/
+/**
+ * xrdp: A Remote Desktop Protocol server.
+ *
+ * Copyright (C) Jay Sorg 2004-2014
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ * main define/macro file
+ */
 
 #ifndef DEFINES_H
 #define DEFINES_H
@@ -74,7 +72,7 @@
   (bpp==8?COLOR8(HRED(c),HGREEN(c),HBLUE(c)): \
    (bpp==15?COLOR15(HRED(c),HGREEN(c),HBLUE(c)): \
     (bpp==16?COLOR16(HRED(c),HGREEN(c),HBLUE(c)): \
-      (bpp==24?COLOR24BGR(HRED(c),HGREEN(c),HBLUE(c)):c) \
+      (bpp>=24?COLOR24BGR(HRED(c),HGREEN(c),HBLUE(c)):c) \
     ) \
    ) \
   ) \
@@ -103,4 +101,10 @@
 /* use crc for bitmap cache lookups */
 #define USE_CRC
 
+#define XR_RGB2BGR(a_ulColor) \
+   (a_ulColor & 0xFF000000) | \
+  ((a_ulColor & 0x00FF0000) >> 16) | \
+   (a_ulColor & 0x0000FF00) |  \
+  ((a_ulColor & 0x000000FF) << 16)
+
 #endif
