@@ -16,6 +16,10 @@
  * limitations under the License.
  */
 
+#if defined(HAVE_CONFIG_H)
+#include <config_ac.h>
+#endif
+
 #include "libxrdp.h"
 #include "xrdp_rail.h"
 
@@ -26,7 +30,7 @@
 /*****************************************************************************/
 /* RAIL */
 /* returns error */
-int APP_CC
+int
 xrdp_orders_send_window_delete(struct xrdp_orders *self, int window_id)
 {
     int order_size;
@@ -57,7 +61,7 @@ xrdp_orders_send_window_delete(struct xrdp_orders *self, int window_id)
 /* returns error */
 /* flags can contain WINDOW_ORDER_STATE_NEW and/or
    WINDOW_ORDER_FIELD_ICON_BIG */
-int APP_CC
+int
 xrdp_orders_send_window_cached_icon(struct xrdp_orders *self,
                                     int window_id, int cache_entry,
                                     int cache_id, int flags)
@@ -93,7 +97,7 @@ xrdp_orders_send_window_cached_icon(struct xrdp_orders *self,
 /*****************************************************************************/
 /* RAIL */
 /* returns error */
-static int APP_CC
+static int
 xrdp_orders_send_ts_icon(struct stream *s, int cache_entry, int cache_id,
                          struct rail_icon_info *icon_info)
 {
@@ -136,7 +140,7 @@ xrdp_orders_send_ts_icon(struct stream *s, int cache_entry, int cache_id,
 /* returns error */
 /* flags can contain WINDOW_ORDER_STATE_NEW and/or
    WINDOW_ORDER_FIELD_ICON_BIG */
-int APP_CC
+int
 xrdp_orders_send_window_icon(struct xrdp_orders *self,
                              int window_id, int cache_entry, int cache_id,
                              struct rail_icon_info *icon_info,
@@ -185,21 +189,27 @@ xrdp_orders_send_window_icon(struct xrdp_orders *self,
 
 /*****************************************************************************/
 /* returns error */
-static int APP_CC
+static int
 xrdp_orders_send_as_unicode(struct stream *s, const char *text)
 {
     int str_chars;
     int index;
     int i32;
-    twchar wdst[256];
+    int len;
+    twchar *wdst;
 
-    str_chars = g_mbstowcs(wdst, text, 255);
+    len = g_strlen(text) + 1;
 
+    wdst = (twchar *) g_malloc(sizeof(twchar) * len, 1);
+    if (wdst == 0)
+    {
+        return 1;
+    }
+    str_chars = g_mbstowcs(wdst, text, len);
     if (str_chars > 0)
     {
         i32 = str_chars * 2;
         out_uint16_le(s, i32);
-
         for (index = 0; index < str_chars; index++)
         {
             i32 = wdst[index];
@@ -210,15 +220,36 @@ xrdp_orders_send_as_unicode(struct stream *s, const char *text)
     {
         out_uint16_le(s, 0);
     }
-
+    g_free(wdst);
     return 0;
 }
 
+/*****************************************************************************/
+static int
+xrdp_orders_get_unicode_bytes(const char *text)
+{
+    int num_chars;
+
+    num_chars = g_mbstowcs(0, text, 0);
+    if (num_chars < 0)
+    {
+        /* g_mbstowcs failed, we ignore that text by returning zero bytes */
+        num_chars = 0;
+    }
+    else
+    {
+        /* calculate the number of bytes of the resulting null-terminated wide-string */
+        num_chars = (num_chars + 1) * 2;
+    }
+
+    return num_chars;
+}
+
 /*****************************************************************************/
 /* RAIL */
 /* returns error */
 /* flags can contain WINDOW_ORDER_STATE_NEW */
-int APP_CC
+int
 xrdp_orders_send_window_new_update(struct xrdp_orders *self, int window_id,
                                    struct rail_window_state_order *window_state,
                                    int flags)
@@ -226,7 +257,6 @@ xrdp_orders_send_window_new_update(struct xrdp_orders *self, int window_id,
     int order_size;
     int order_flags;
     int field_present_flags;
-    int num_chars;
     int index;
 
     order_size = 11;
@@ -255,8 +285,7 @@ xrdp_orders_send_window_new_update(struct xrdp_orders *self, int window_id,
     if (field_present_flags & WINDOW_ORDER_FIELD_TITLE)
     {
         /* titleInfo */
-        num_chars = g_mbstowcs(0, window_state->title_info, 0);
-        order_size += 2 * num_chars + 2;
+        order_size += xrdp_orders_get_unicode_bytes(window_state->title_info);
     }
 
     if (field_present_flags & WINDOW_ORDER_FIELD_CLIENT_AREA_OFFSET)
@@ -474,7 +503,7 @@ xrdp_orders_send_window_new_update(struct xrdp_orders *self, int window_id,
 /*****************************************************************************/
 /* RAIL */
 /* returns error */
-int APP_CC
+int
 xrdp_orders_send_notify_delete(struct xrdp_orders *self, int window_id,
                                int notify_id)
 {
@@ -507,7 +536,7 @@ xrdp_orders_send_notify_delete(struct xrdp_orders *self, int window_id,
 /* RAIL */
 /* returns error */
 /* flags can contain WINDOW_ORDER_STATE_NEW */
-int APP_CC
+int
 xrdp_orders_send_notify_new_update(struct xrdp_orders *self,
                                    int window_id, int notify_id,
                                    struct rail_notify_state_order *notify_state,
@@ -516,7 +545,6 @@ xrdp_orders_send_notify_new_update(struct xrdp_orders *self,
     int order_size;
     int order_flags;
     int field_present_flags;
-    int num_chars;
     int use_cmap;
 
     order_size = 15;
@@ -531,19 +559,16 @@ xrdp_orders_send_notify_new_update(struct xrdp_orders *self,
     if (field_present_flags & WINDOW_ORDER_FIELD_NOTIFY_TIP)
     {
         /* ToolTip (variable) UNICODE_STRING */
-        num_chars = g_mbstowcs(0, notify_state->tool_tip, 0);
-        order_size += 2 * num_chars + 2;
+        order_size += xrdp_orders_get_unicode_bytes(notify_state->tool_tip);
     }
 
     if (field_present_flags & WINDOW_ORDER_FIELD_NOTIFY_INFO_TIP)
     {
         /* InfoTip (variable) TS_NOTIFY_ICON_INFOTIP */
         /* UNICODE_STRING */
-        num_chars = g_mbstowcs(0, notify_state->infotip.title, 0);
-        order_size += 2 * num_chars + 2;
+        order_size += xrdp_orders_get_unicode_bytes(notify_state->infotip.title);
         /* UNICODE_STRING */
-        num_chars = g_mbstowcs(0, notify_state->infotip.text, 0);
-        order_size += 2 * num_chars + 2;
+        order_size += xrdp_orders_get_unicode_bytes(notify_state->infotip.text);
         /* Timeout (4 bytes) */
         /* InfoFlags (4 bytes) */
         order_size += 8;
@@ -648,7 +673,7 @@ xrdp_orders_send_notify_new_update(struct xrdp_orders *self,
 /* RAIL */
 /* returns error */
 /* used for both Non-Monitored Desktop and Actively Monitored Desktop */
-int APP_CC
+int
 xrdp_orders_send_monitored_desktop(struct xrdp_orders *self,
                                    struct rail_monitored_desktop_order *mdo,
                                    int flags)
