@@ -24,6 +24,10 @@
  *
  */
 
+#if defined(HAVE_CONFIG_H)
+#include <config_ac.h>
+#endif
+
 #include "arch.h"
 #include "list.h"
 #include "file.h"
@@ -35,7 +39,7 @@ extern struct config_sesman *g_cfg; /* in sesman.c */
 
 
 /******************************************************************************/
-int DEFAULT_CC
+int
 config_read(struct config_sesman *cfg)
 {
     int fd;
@@ -99,7 +103,7 @@ config_read(struct config_sesman *cfg)
 }
 
 /******************************************************************************/
-int DEFAULT_CC
+int
 config_read_globals(int file, struct config_sesman *cf, struct list *param_n,
                     struct list *param_v)
 {
@@ -183,7 +187,7 @@ config_read_globals(int file, struct config_sesman *cf, struct list *param_n,
 }
 
 /******************************************************************************/
-int DEFAULT_CC
+int
 config_read_security(int file, struct config_security *sc,
                      struct list *param_n,
                      struct list *param_v)
@@ -268,7 +272,7 @@ config_read_security(int file, struct config_security *sc,
 }
 
 /******************************************************************************/
-int DEFAULT_CC
+int
 config_read_sessions(int file, struct config_sessions *se, struct list *param_n,
                      struct list *param_v)
 {
@@ -357,14 +361,14 @@ config_read_sessions(int file, struct config_sessions *se, struct list *param_n,
     g_printf("\tX11DisplayOffset:            %i\r\n", se->x11_display_offset);
     g_printf("\tKillDisconnected:            %i\r\n", se->kill_disconnected);
     g_printf("\tIdleTimeLimit:               %i\r\n", se->max_idle_time);
-    g_printf("\tDisconnectedTimeLimit:       %i\r\n", se->max_idle_time);
+    g_printf("\tDisconnectedTimeLimit:       %i\r\n", se->max_disc_time);
     g_printf("\tPolicy:       %i\r\n", se->policy);
 
     return 0;
 }
 
 /******************************************************************************/
-int DEFAULT_CC
+int
 config_read_rdp_params(int file, struct config_sesman *cs, struct list *param_n,
                        struct list *param_v)
 {
@@ -395,7 +399,7 @@ config_read_rdp_params(int file, struct config_sesman *cs, struct list *param_n,
 }
 
 /******************************************************************************/
-int DEFAULT_CC
+int
 config_read_xorg_params(int file, struct config_sesman *cs,
                         struct list *param_n, struct list *param_v)
 {
@@ -428,7 +432,7 @@ config_read_xorg_params(int file, struct config_sesman *cs,
 }
 
 /******************************************************************************/
-int DEFAULT_CC
+int
 config_read_vnc_params(int file, struct config_sesman *cs, struct list *param_n,
                        struct list *param_v)
 {
@@ -459,7 +463,7 @@ config_read_vnc_params(int file, struct config_sesman *cs, struct list *param_n,
 }
 
 /******************************************************************************/
-int DEFAULT_CC
+int
 config_read_session_variables(int file, struct config_sesman *cs,
                               struct list *param_n, struct list *param_v)
 {
